==> prodiapy-2.4-py3-none-any.whl: prodia/data.py <==
class Models:
    sd14 = "sdv1_4.ckpt [7460a6fa]"
    sd15 = "v1-5-pruned-emaonly.ckpt [81761151]"
    anyv3 = "anythingv3_0-pruned.ckpt [2700c435]"
    anyv4 = "anything-v4.5-pruned.ckpt [65745d25]"
    analog = "analog-diffusion-1.0.ckpt [9ca13f02]"
    theallys = "theallys-mix-ii-churned.safetensors [5d9225a4]"
    elldreths = "elldreths-vivid-mix.safetensors [342d9d26]"
    delibrate = "deliberate_v2.safetensors [10ec4b29]"
    openjourney = "openjourney_V4.ckpt [ca2f377f]"
    dreaml1 = "dreamlike-diffusion-1.0.safetensors [5c9fd6e0]"
    dreaml2 = "dreamlike-diffusion-2.0.safetensors [fdcf65e7]"
    portrait = "portrait+1.0.safetensors [1400e684]"
    riffusion = "riffusion-model-v1.ckpt [3aafa6fe]"
    timeless = "timeless-1.0.ckpt [7c4971d4]"
    dreamsh = "dreamshaper_5BakedVae.safetensors [a3fbf318]"
    revA = "revAnimated_v122.safetensors [3f4fefd9]"
    meina = "meinamix_meinaV9.safetensors [2ec66ab0]"
    lyriel = "lyriel_v15.safetensors [65d547c5]"
    mlist = [
        "sdv1_4.ckpt [7460a6fa]",
        "v1-5-pruned-emaonly.ckpt [81761151]",
        "anythingv3_0-pruned.ckpt [2700c435]",
        "anything-v4.5-pruned.ckpt [65745d25]",
        "analog-diffusion-1.0.ckpt [9ca13f02]",
        "theallys-mix-ii-churned.safetensors [5d9225a4]",
        "elldreths-vivid-mix.safetensors [342d9d26]",
        "deliberate_v2.safetensors [10ec4b29]",
        "openjourney_V4.ckpt [ca2f377f]",
        "dreamlike-diffusion-1.0.safetensors [5c9fd6e0]",
        "dreamlike-diffusion-2.0.safetensors [fdcf65e7]",
        "portrait+1.0.safetensors [1400e684]",
        "riffusion-model-v1.ckpt [3aafa6fe]",
        "timeless-1.0.ckpt [7c4971d4]",
        "dreamshaper_5BakedVae.safetensors [a3fbf318]",
        "revAnimated_v122.safetensors [3f4fefd9]",
        "meinamix_meinaV9.safetensors [2ec66ab0]",
        "lyriel_v15.safetensors [65d547c5]"
    ]

class Samplers:
    euler = "Euler"
    euler_a = "Euler a"
    heun = "Heun"
    dpm = "DPM++ 2M Karras"
    slist = [
        "Euler",
        "Euler a",
        "Heun",
        "DPM++ 2M Karras"
    ]

class ar:
    alist = [
        "square",
        "landscape",
        "portrait"
    ]

==> prodiapy-2.5-py3-none-any.whl: prodia/data.py <==
class Models:
    sd14 = "sdv1_4.ckpt [7460a6fa]"
    sd15 = "v1-5-pruned-emaonly.ckpt [81761151]"
    anyv3 = "anythingv3_0-pruned.ckpt [2700c435]"
    anyv4 = "anything-v4.5-pruned.ckpt [65745d25]"
    analog = "analog-diffusion-1.0.ckpt [9ca13f02]"
    theallys = "theallys-mix-ii-churned.safetensors [5d9225a4]"
    elldreths = "elldreths-vivid-mix.safetensors [342d9d26]"
    deliberate = "deliberate_v2.safetensors [10ec4b29]"
    openjourney = "openjourney_V4.ckpt [ca2f377f]"
    dreaml1 = "dreamlike-diffusion-1.0.safetensors [5c9fd6e0]"
    dreaml2 = "dreamlike-diffusion-2.0.safetensors [fdcf65e7]"
    portrait = "portrait+1.0.safetensors [1400e684]"
    riffusion = "riffusion-model-v1.ckpt [3aafa6fe]"
    timeless = "timeless-1.0.ckpt [7c4971d4]"
    dreamsh = "dreamshaper_5BakedVae.safetensors [a3fbf318]"
    revA = "revAnimated_v122.safetensors [3f4fefd9]"
    meina = "meinamix_meinaV9.safetensors [2ec66ab0]"
    lyriel = "lyriel_v15.safetensors [65d547c5]"
    realistic = "Realistic_Vision_V2.0.safetensors [79587710]"
    mlist = [
        "sdv1_4.ckpt [7460a6fa]",
        "v1-5-pruned-emaonly.ckpt [81761151]",
        "anythingv3_0-pruned.ckpt [2700c435]",
        "anything-v4.5-pruned.ckpt [65745d25]",
        "analog-diffusion-1.0.ckpt [9ca13f02]",
        "theallys-mix-ii-churned.safetensors [5d9225a4]",
        "elldreths-vivid-mix.safetensors [342d9d26]",
        "deliberate_v2.safetensors [10ec4b29]",
        "openjourney_V4.ckpt [ca2f377f]",
        "dreamlike-diffusion-1.0.safetensors [5c9fd6e0]",
        "dreamlike-diffusion-2.0.safetensors [fdcf65e7]",
        "portrait+1.0.safetensors [1400e684]",
        "riffusion-model-v1.ckpt [3aafa6fe]",
        "timeless-1.0.ckpt [7c4971d4]",
        "dreamshaper_5BakedVae.safetensors [a3fbf318]",
        "revAnimated_v122.safetensors [3f4fefd9]",
        "meinamix_meinaV9.safetensors [2ec66ab0]",
        "lyriel_v15.safetensors [65d547c5]"
    ]

class Samplers:
    euler = "Euler"
    euler_a = "Euler a"
    heun = "Heun"
    dpm = "DPM++ 2M Karras"
    slist = [
        "Euler",
        "Euler a",
        "Heun",
        "DPM++ 2M Karras"
    ]

class ar:
    alist = [
        "square",
        "landscape",
        "portrait"
    ]
